<?php

namespace App\Repositories\Conversation;


interface ConversationRepositoryInterface
{
    public function create($data);
    public function query();
    public function findByPhone($phone);
    public function activatedCustomer($id);
    public function disabledConversation($id);
    public function activatedConversation($id);

    public function updateLastMessage($id);
    public function updateStatusIA($id,$status);
    public function updateThreadPhone($phone, $threadId);

}
